@@ -17,12 +17,17 @@ import glean_parser
 
 
 from . import coverage as mod_coverage
+from . import data_review as mod_data_review
 from . import lint
 from . import translate as mod_translate
 from . import validate_ping
+from . import translation_options
 
 
-@click.command()
+CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+
+
+@click.command(context_settings=CONTEXT_SETTINGS)
 @click.argument(
     "input",
     type=click.Path(exists=False, dir_okay=False, file_okay=True, readable=True),
@@ -44,10 +49,13 @@ from . import validate_ping
 @click.option(
     "--option",
     "-s",
-    help="backend-specific option. Must be of the form key=value",
+    help="Backend-specific option. Must be of the form key=value.\
+ Pass 'help' for valid options",
     type=str,
     multiple=True,
     required=False,
+    is_eager=True,
+    callback=translation_options.translate_options,
 )
 @click.option(
     "--allow-reserved",
@@ -62,7 +70,27 @@ from . import validate_ping
     is_flag=True,
     help=("Do not treat missing input files as an error."),
 )
-def translate(input, format, output, option, allow_reserved, allow_missing_files):
+@click.option(
+    "--require-tags",
+    is_flag=True,
+    help=("Require tags to be specified for metrics and pings."),
+)
+@click.option(
+    "--expire-by-version",
+    help="Expire metrics by version, with the provided major version.",
+    type=click.INT,
+    required=False,
+)
+def translate(
+    input,
+    format,
+    output,
+    option,
+    allow_reserved,
+    allow_missing_files,
+    require_tags,
+    expire_by_version,
+):
     """
     Translate metrics.yaml and pings.yaml files to other formats.
     """
@@ -80,6 +108,8 @@ def translate(input, format, output, option, allow_reserved, allow_missing_files
             {
                 "allow_reserved": allow_reserved,
                 "allow_missing_files": allow_missing_files,
+                "require_tags": require_tags,
+                "expire_by_version": expire_by_version,
             },
         )
     )
@@ -129,7 +159,12 @@ def check(schema):
     is_flag=True,
     help=("Do not treat missing input files as an error."),
 )
-def glinter(input, allow_reserved, allow_missing_files):
+@click.option(
+    "--require-tags",
+    is_flag=True,
+    help=("Require tags to be specified for metrics and pings."),
+)
+def glinter(input, allow_reserved, allow_missing_files, require_tags):
     """
     Runs a linter over the metrics.
     """
@@ -139,6 +174,7 @@ def glinter(input, allow_reserved, allow_missing_files):
             {
                 "allow_reserved": allow_reserved,
                 "allow_missing_files": allow_missing_files,
+                "require_tags": require_tags,
             },
         )
     )
@@ -195,6 +231,26 @@ def coverage(coverage_file, metrics_files, format, output, allow_reserved):
     )
 
 
+@click.command()
+@click.argument("bug", type=str)
+@click.argument(
+    "metrics_files",
+    type=click.Path(exists=True, dir_okay=False, file_okay=True, readable=True),
+    nargs=-1,
+)
+def data_review_request(bug, metrics_files):
+    """
+    Generate a skeleton Data Review Request for all metrics in metrics_files
+    whose bug_numbers fields contain the provided bug string.
+    For example, providing "1694739" matches
+    "https://bugzilla.mozilla.org/show_bug.cgi?id=1694739".
+    To ensure substrings don't match, the provided bug string will match only
+    if it is bounded by non-word characters.
+    Prints to stdout.
+    """
+    sys.exit(mod_data_review.generate(bug, [Path(x) for x in metrics_files]))
+
+
 @click.group()
 @click.version_option(glean_parser.__version__, prog_name="glean_parser")
 def main(args=None):
@@ -206,6 +262,7 @@ main.add_command(translate)
 main.add_command(check)
 main.add_command(glinter)
 main.add_command(coverage)
+main.add_command(data_review_request, "data-review")
 
 
 def main_wrapper(args=None):
